<?xml version='1.0'?>

<!-- ************************************************************* -->
<!-- XSLT 1.0 Transformation Sheet for the Bimodal DTD             -->
<!-- Most Recent Revision: 2001-01-05                              -->
<!--                                                               -->
<!-- Creates a series of linked HTML pages to be used as "slides"  -->
<!-- for course/tutorial presentations prepared using the XML      -->
<!-- version of the Bimodal DTD (v0.9a).                           -->
<!--                                                               -->
<!-- Disclaimer: I am not a programmer.  There are probably far    -->
<!-- more elegant ways to produce the same effects, but my goal    -->
<!-- was to create an easy and easy-to-explain transformation that -->
<!-- would simultaneously satisfy my requirements.                 -->
<!--                                                               -->
<!-- This stylesheet is continually revised as I come across new   -->
<!-- and interesting techniques.  I currently use Michael Kay's    -->
<!-- Instant Saxon (v6.2.2) for production work, so this script    -->
<!-- uses the Saxon extensions for multiple output.  Clever folks  -->
<!-- familiar with other XSLT processors are welcome to adapt it.  -->
<!--                                                               -->
<!-- To-do list:                                                   -->
<!--      1) Clean up messy CSS                                    -->
<!--      2) Tables                                                -->
<!--      3) Interesting link behavior                             -->
<!--                                                               -->
<!-- See embedded comments for further documentation.  Use at your -->
<!-- own risk.  May cause blurred vision and boils.                -->
<!--                                                               -->
<!-- Useful and clever suggestions may be sent to the author at:   -->
<!--                                                               -->
<!--                    sgml.xml@att.net                           -->
<!--                                                               -->
<!-- If you give me credit, I'll give you credit. - Michael Hahn   -->
<!--                                                               -->
<!-- ************************************************************* -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://icl.com/saxon"
                extension-element-prefixes="saxon" >

<xsl:output method="xml" indent="yes"/>
<xsl:preserve-space elements="line"/>

<!-- ************************************************************* -->
<!-- Root element of the Bimodal DTD is article                    -->
<!-- ************************************************************* -->

<xsl:template match="article">

<!-- ************************************************************* -->
<!-- Output the title slide                                        -->
<!-- ************************************************************* -->

<saxon:output href="./Slides/1stslide.html">
<html>
<head>
<meta name="source" content="Converted from XML using XSLT"/>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
<title><xsl:value-of select="./title"/> - Copyright &#169; 2001 <xsl:value-of select="metadata/author"/></title>
</head>
<!-- ************************************************************* -->
<!-- Change the img element to whatever you intend to use as a     -->
<!-- button for advancing to the next slide                        -->
<!-- ************************************************************* -->
<body style="background-color: navy; color: yellow; margin-left: 7em; margin-right: 7em">
<p style="text-align: right"><a href="{./hook/@pointer}.html"><img src="logo.jpg" alt="click me!"/></a></p>
<h1 style="font-size: 36pt; margin-top: 2em; text-align: center"><xsl:value-of select="title"/></h1>
<h1 style="font-size: 28pt; text-align: center"><xsl:value-of select="subtitle"/></h1>
<h1 style="font-size: 20pt; margin-top: 2em; margin-bottom: 4em; text-align: center"><xsl:value-of select="metadata/date"/></h1>
<p style="font-size: 16pt; text-align: center">
<xsl:value-of select="metadata/author"/><br class="hack"/>
(<i><xsl:value-of select="metadata/author/@e-mail"/></i>)<br class="hack"/>
<xsl:value-of select="metadata/affil"/>
</p>
</body>
</html>
</saxon:output>

<!-- ************************************************************* -->
<!-- Output each major division slide                              -->
<!-- ************************************************************* -->

<xsl:for-each select="body/section">
<saxon:output href="./Slides/{./hook/@target}.html">
<html>
<head>
<meta name="source" content="Converted from XML using XSL"/>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
<title><xsl:value-of select="./title"/> - Copyright &#169; 2001 <xsl:value-of select="/article/metadata/author"/></title>
</head>
<!-- ************************************************************* -->
<!-- Change the img element to whatever you intend to use as a     -->
<!-- button for advancing to the next slide                        -->
<!-- ************************************************************* -->
<body style="background-color: navy; color: yellow; margin-left: 7em; margin-right: 7em">
<p style="text-align: right"><a href="{./hook/@pointer}.html"><img src="logo.jpg"/></a></p>
<h1 style="margin-top: 5em; margin-bottom: 1em; text-align: center"><xsl:value-of select="title"/></h1>
</body>
</html>
</saxon:output>
</xsl:for-each>

<!-- ************************************************************* -->
<!-- Output the main body slides                                   -->
<!-- ************************************************************* -->

<xsl:for-each select="body/section/section">
<saxon:output href="./Slides/{./hook/@target}.html">
<html>
<head>
<meta name="source" content="Converted from XML using XSL"/>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
<title><xsl:value-of select="./title"/> - Copyright &#169; 2001 <xsl:value-of select="/article/metadata/author"/></title>
</head>
<body style="background-color: navy; color: yellow; margin-left: 7em; margin-right: 7em">
<!-- ************************************************************* -->
<!-- Change the img element to whatever you intend to use as a     -->
<!-- button for advancing to the next slide                        -->
<!-- ************************************************************* -->
<p style="text-align: right"><a href="{./hook/@pointer}.html"><img src="logo.jpg"/></a></p>
<xsl:apply-templates/>
</body>
</html>
</saxon:output>
</xsl:for-each>
</xsl:template>
                                                                   
<!-- ************************************************************* -->
<!-- Templates for title levels                                    -->
<!-- ************************************************************* -->

<xsl:template match="article/title">
<h1 style="margin-top: 3em; margin-bottom: 1em; text-align: center"><xsl:apply-templates/></h1>
</xsl:template>

<xsl:template match="article/body/section/title">
<h1 style="margin-top: 1em; margin-bottom: 1em; text-align: center"><u><xsl:apply-templates/></u></h1>
</xsl:template>

<xsl:template match="article/body/section/section/title">
<h1 style="margin-top: 1em; margin-bottom: 1em; text-align: center"><xsl:apply-templates/></h1>
</xsl:template>

<!-- ************************************************************* -->
<!-- Templates for assorted structures                             -->
<!-- Note: Not all structures described in the DTD have defined    -->
<!-- templates yet!                                                -->
<!-- ************************************************************* -->

<xsl:template match="summary">
<div style="font-size: 18pt">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="para">
<p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="inlinecode">
<code style="color: white; font-size: 16pt"><xsl:apply-templates/></code>
</xsl:template>

<xsl:template match="code">
<p>
<xsl:apply-templates/>
</p>
</xsl:template>

<xsl:template match="line">
<code style="color: white; font-size: 16pt"><xsl:apply-templates/></code><br class="hack"/>
</xsl:template>

<xsl:template match="quote">
&#8220;<xsl:apply-templates/>&#8221;
</xsl:template>

<xsl:template match="graphic">
<p style="text-align: center"><img src="{unparsed-entity-uri(@image)}"/></p>
</xsl:template>

<xsl:template match="emph">
<i><xsl:apply-templates/></i>
</xsl:template>

<xsl:template match="break">
<br class="hack"/>
</xsl:template>

<!-- ************************************************************* -->
<!-- Templates for nested lists                                    -->
<!-- ************************************************************* -->

<xsl:template match="list[@listtype='unordered']">
<ul type="disc"><xsl:apply-templates/></ul>
</xsl:template>

<xsl:template match="list[@listtype='unordered']//list[@listtype='unordered']">
<ul type="square"><xsl:apply-templates/></ul>
</xsl:template>

<xsl:template match="list[@listtype='ordered']">
<ol type="1"><xsl:apply-templates/></ol>
</xsl:template>

<xsl:template match="list[@listtype='ordered']//list[@listtype='ordered']">
<ol type="a"><xsl:apply-templates/></ol>
</xsl:template>

<xsl:template match="listitem">
<li><xsl:apply-templates/></li>
</xsl:template>

<xsl:template match="listitem/para">
<xsl:apply-templates/><br class="hack"/>
</xsl:template>                                                    

<xsl:template match="def.list">
<table style="font-size: 18pt" cellspacing="20">
<xsl:apply-templates/>
</table>
</xsl:template>

<xsl:template match="def.list.head">
<tr valign="top"><th><xsl:apply-templates select="term.head"/></th><th><xsl:apply-templates select="def.head"/></th></tr>
</xsl:template>

<xsl:template match="def.item">
<tr valign="top"><td><i><xsl:apply-templates select="term"/></i></td><td><xsl:apply-templates select="def"/></td></tr>
</xsl:template>

<!-- ************************************************************* -->
<!-- Null templates                                                -->
<!-- ************************************************************* -->

<xsl:template match="exercise">
</xsl:template>

<xsl:template match="section/para">
</xsl:template>

</xsl:stylesheet>
